.. _user_guide:

User Guide
**********

Jupyter Notebooks
=================
For interactively exploring data in a Data Cube, we recommend using `Jupyter
Notebooks <http://jupyter.org/>`_.


Standalone Tools
================
The Data Cube software comes with several tools that can be used for data
exploration and exporting, without writing any code.

* `datacube` (see ``datacube --help`` after installation)
* `pixeldrill`
* `movie_generator`



